﻿© 2010 Fluke Corporation, All rights reserved               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub MG369XB Calculate External AM /8901,LO,FGEN
INSTRUMENT:            Sub MG369XB Calculate AM Roll Off /8901,LO,FGEN
INSTRUMENT:            Sub MG369XB Calculate AM Flatness /8901,LO,FGEN
DATE:                  2010-02-10 07:18:01
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       4
NUMBER OF LINES:       349
CONFIGURATION:         HP 8901B
CONFIGURATION:         Local Oscillator
CONFIGURATION:         Function Generator
=============================================================================
#
#  Procedure Author:
#        DAC
#
#  Model(s) Covered:
#        MG369XB
#
#  Compatibility:
#        MET/CAL V7.20 SP1 (7.20x) or later
#
#  Subprocedures:
#        Sub MG369XB Reset & SRQ Masks
#        Sub Apply /LO
#        Sub Apply /FGEN
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Dummy statements to force header to contain reference used in subprocedure.
  1.001  IF           0
  1.002  IEEE         [@LO]
  1.002  IEEE         [@FGEN]
  1.003  ENDIF

  1.004  MATH         DevName = "HP 8901B"

  1.005  JMPL         EXTERNAL_AM                  PSUB("External AM")
  1.006  JMPL         AM_ROLL_OFF                  PSUB("AM Roll Off")
  1.007  JMPL         AM_FLATNESS                  PSUB("AM Flatness")
  1.008  DISP         Called subprocedure not found!
  1.009  END

  1.010  EVAL   Increment step number

# =====  Sub MG369XB Calculate External AM /8901,LO,FGEN  ===================

  2.001  LABEL        EXTERNAL_AM
  2.002  MATH         @FGEN_Freq = "1 kHz"; @FGEN_Ampl = @FGEN_Ampl_1kHz
  2.003  TARGET
# The 8901 must be setup for each iteration of the TARGET -m loop because
# a peak+ and peak- reading are taken.
  2.004  TSET         MEASURE_ONLY = No
  2.005  CALL         Sub Apply /LO
  2.006  CALL         Sub Apply /FGEN
  2.007  IEEE         RF1[D50]
  2.008  M8901        1kH                                         H2 L2    P+

# 1 GHz test uses 8901 IF Freq of 600.53 MHz.
  2.009  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  2.010  8901         50pct                        600.53MH          AM N
  2.011  ELSE
  2.012  8901         50pct                        120.53MH          AM N
  2.013  ENDIF

  2.014  MATH         Pk1 = MEM; AccPos = (REFACC() / MEM) * 100
  2.015  M8901        1kH                                         H2 L2    P-

  2.016  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  2.017  8901         50pct                        600.53MH          AM N
  2.018  ELSE
  2.019  8901         50pct                        120.53MH          AM N
  2.020  ENDIF

  2.021  MATH         Pk2 = MEM; AccNeg = (REFACC() / MEM) * 100
  2.022  MATH         M = ((Pk1 + Pk2) / (200 + Pk1 - Pk2)) * 100
  2.023  MATH         MEM = CRND(M, 0.01)
  2.024  MATH         M[1] = RSS2(AccPos, AccNeg)

  2.025  END

  2.026  EVAL   Increment step number

# =====  Sub MG369XB Calculate AM Roll Off /8901,LO,FGEN  ===================

  3.001  LABEL        AM_ROLL_OFF
  3.002  HEAD         AM ROLL OFF
  3.003  TARGET
# The 8901 must be setup for each iteration of the TARGET -m loop because
# a 1 kHz and 50 kHz reading are taken.
  3.004  TSET         MEASURE_ONLY = No
  3.005  CALL         Sub Apply /LO
  3.006  IEEE         RF1[D50]

  3.007  HEAD         -2 [V @FreqGHz] GHz, 1 kHz
  3.008  MATH         @FGEN_Freq = "1 kHz"; @FGEN_Ampl = @FGEN_Ampl_1kHz
  3.009  CALL         Sub Apply /FGEN
  3.010  M8901        1kH                                         H0 L0    P+

  3.011  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  3.012  8901         50pct                        600.53MH          AM N
  3.013  ELSE
  3.014  8901         50pct                        120.53MH          AM N
  3.015  ENDIF

  3.016  MATH         AM1 = MEM; Acc1kHz = (REFACC() / MEM) * 100

  3.017  HEAD         -2 [V @FreqGHz] GHz, 50 kHz
  3.018  MATH         @FGEN_Freq = "50 kHz"; @FGEN_Ampl = @FGEN_Ampl_50kHz
  3.019  CALL         Sub Setup /FGEN
  3.020  M8901        50kH                                        H0 L0    P+

  3.021  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  3.022  8901         50pct                        600.53MH          AM N
  3.023  ELSE
  3.024  8901         50pct                        120.53MH          AM N
  3.025  ENDIF

  3.026  MATH         AM50 = MEM; Acc50kHz = (REFACC() / MEM) * 100
  3.027  MATH         MEM = CRND((20 * LOG(AM50 / AM1)), 0.01)
# Compute resulting system accuracy and convert to dB.
  3.028  MATH         M[1] = PCTTODBV_D(RSS2(Acc1kHz, Acc50kHz))

  3.029  HEAD
  3.030  HEAD         -2
  3.031  END

  3.032  EVAL   Increment step number

# =====  Sub MG369XB Calculate AM Flatness /8901,LO,FGEN  ===================

  4.001  LABEL        AM_FLATNESS
  4.002  HEAD         AM FLATNESS
  4.003  TARGET
# The 8901 must be setup for each iteration of the TARGET -m loop because
# a 1 kHz to 10 kHz readings are taken.
  4.004  TSET         MEASURE_ONLY = No
  4.005  CALL         Sub Apply /LO
  4.006  IEEE         RF1[D50]

  4.007  HEAD         -2 [V @FreqGHz] GHz, 1 kHz
  4.008  MATH         @FGEN_Freq = "1 kHz"; @FGEN_Ampl = @FGEN_Ampl_1kHz
  4.009  CALL         Sub Apply /FGEN
  4.010  M8901        1kH                                         H0 L0    P+

  4.011  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  4.012  8901         50pct                        600.53MH          AM N
  4.013  ELSE
  4.014  8901         50pct                        120.53MH          AM N
  4.015  ENDIF

# Convert to proportional parts.
  4.016  MATH         Acc = (REFACC() / MEM) * 100
  4.017  MATH         AMmin = MEM; AccAMmin = Acc
  4.018  MATH         AMmax = MEM; AccAMmax = Acc

  4.019  HEAD         -2 [V @FreqGHz] GHz, 2 kHz
  4.020  MATH         @FGEN_Freq = "2 kHz"; @FGEN_Ampl = @FGEN_Ampl_2kHz
  4.021  CALL         Sub Setup /FGEN
  4.022  M8901        2kH                                         H0 L0    P+

  4.023  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  4.024  8901         50pct                        600.53MH          AM N
  4.025  ELSE
  4.026  8901         50pct                        120.53MH          AM N
  4.027  ENDIF

  4.028  MATH         Acc = (REFACC() / MEM) * 100

  4.029  IF           MEM < AMmin
  4.030  MATH         AMmin = MEM; AccAMmin = Acc
  4.031  ELSEIF       MEM > AMmax
  4.032  MATH         AMmax = MEM; AccAMmax = Acc
  4.033  ENDIF

  4.034  HEAD         -2 [V @FreqGHz] GHz, 3 kHz
  4.035  MATH         @FGEN_Freq = "3 kHz"; @FGEN_Ampl = @FGEN_Ampl_3kHz
  4.036  CALL         Sub Setup /FGEN
  4.037  M8901        3kH                                         H0 L0    P+

  4.038  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  4.039  8901         50pct                        600.53MH          AM N
  4.040  ELSE
  4.041  8901         50pct                        120.53MH          AM N
  4.042  ENDIF

  4.043  MATH         Acc = (REFACC() / MEM) * 100

  4.044  IF           MEM < AMmin
  4.045  MATH         AMmin = MEM; AccAMmin = Acc
  4.046  ELSEIF       MEM > AMmax
  4.047  MATH         AMmax = MEM; AccAMmin = Acc
  4.048  ENDIF

  4.049  HEAD         -2 [V @FreqGHz] GHz, 4 kHz
  4.050  MATH         @FGEN_Freq = "4 kHz"; @FGEN_Ampl = @FGEN_Ampl_4kHz
  4.051  CALL         Sub Setup /FGEN
  4.052  M8901        4kH                                         H0 L0    P+

  4.053  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  4.054  8901         50pct                        600.53MH          AM N
  4.055  ELSE
  4.056  8901         50pct                        120.53MH          AM N
  4.057  ENDIF

  4.058  MATH         Acc = (REFACC() / MEM) * 100

  4.059  IF           MEM < AMmin
  4.060  MATH         AMmin = MEM; AccAMmin = Acc
  4.061  ELSEIF       MEM > AMmax
  4.062  MATH         AMmax = MEM; AccAMmin = Acc
  4.063  ENDIF

  4.064  HEAD         -2 [V @FreqGHz] GHz, 5 kHz
  4.065  MATH         @FGEN_Freq = "5 kHz"; @FGEN_Ampl = @FGEN_Ampl_5kHz
  4.066  CALL         Sub Setup /FGEN
  4.067  M8901        5kH                                         H0 L0    P+

  4.068  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  4.069  8901         50pct                        600.53MH          AM N
  4.070  ELSE
  4.071  8901         50pct                        120.53MH          AM N
  4.072  ENDIF

  4.073  MATH         Acc = (REFACC() / MEM) * 100

  4.074  IF           MEM < AMmin
  4.075  MATH         AMmin = MEM; AccAMmin = Acc
  4.076  ELSEIF       MEM > AMmax
  4.077  MATH         AMmax = MEM; AccAMmin = Acc
  4.078  ENDIF

  4.079  HEAD         -2 [V @FreqGHz] GHz, 6 kHz
  4.080  MATH         @FGEN_Freq = "6 kHz"; @FGEN_Ampl = @FGEN_Ampl_6kHz
  4.081  CALL         Sub Setup /FGEN
  4.082  M8901        6kH                                         H0 L0    P+

  4.083  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  4.084  8901         50pct                        600.53MH          AM N
  4.085  ELSE
  4.086  8901         50pct                        120.53MH          AM N
  4.087  ENDIF

  4.088  MATH         Acc = (REFACC() / MEM) * 100

  4.089  IF           MEM < AMmin
  4.090  MATH         AMmin = MEM; AccAMmin = Acc
  4.091  ELSEIF       MEM > AMmax
  4.092  MATH         AMmax = MEM; AccAMmin = Acc
  4.093  ENDIF

  4.094  HEAD         -2 [V @FreqGHz] GHz, 7 kHz
  4.095  MATH         @FGEN_Freq = "7 kHz"; @FGEN_Ampl = @FGEN_Ampl_7kHz
  4.096  CALL         Sub Setup /FGEN
  4.097  M8901        7kH                                         H0 L0    P+

  4.098  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  4.099  8901         50pct                        600.53MH          AM N
  4.100  ELSE
  4.101  8901         50pct                        120.53MH          AM N
  4.102  ENDIF

  4.103  MATH         Acc = (REFACC() / MEM) * 100

  4.104  IF           MEM < AMmin
  4.105  MATH         AMmin = MEM; AccAMmin = Acc
  4.106  ELSEIF       MEM > AMmax
  4.107  MATH         AMmax = MEM; AccAMmin = Acc
  4.108  ENDIF

  4.109  HEAD         -2 [V @FreqGHz] GHz, 8 kHz
  4.110  MATH         @FGEN_Freq = "8 kHz"; @FGEN_Ampl = @FGEN_Ampl_8kHz
  4.111  CALL         Sub Setup /FGEN
  4.112  M8901        8kH                                         H0 L0    P+

  4.113  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  4.114  8901         50pct                        600.53MH          AM N
  4.115  ELSE
  4.116  8901         50pct                        120.53MH          AM N
  4.117  ENDIF

  4.118  MATH         Acc = (REFACC() / MEM) * 100

  4.119  IF           MEM < AMmin
  4.120  MATH         AMmin = MEM; AccAMmin = Acc
  4.121  ELSEIF       MEM > AMmax
  4.122  MATH         AMmax = MEM; AccAMmin = Acc
  4.123  ENDIF

  4.124  HEAD         -2 [V @FreqGHz] GHz, 9 kHz
  4.125  MATH         @FGEN_Freq = "9 kHz"; @FGEN_Ampl = @FGEN_Ampl_9kHz
  4.126  CALL         Sub Setup /FGEN
  4.127  M8901        9kH                                         H0 L0    P+

  4.128  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  4.129  8901         50pct                        600.53MH          AM N
  4.130  ELSE
  4.131  8901         50pct                        120.53MH          AM N
  4.132  ENDIF

  4.133  MATH         Acc = (REFACC() / MEM) * 100

  4.134  IF           MEM < AMmin
  4.135  MATH         AMmin = MEM; AccAMmin = Acc
  4.136  ELSEIF       MEM > AMmax
  4.137  MATH         AMmax = MEM; AccAMmin = Acc
  4.138  ENDIF

  4.139  HEAD         -2 [V @FreqGHz] GHz, 10 kHz
  4.140  MATH         @FGEN_Freq = "10 kHz"; @FGEN_Ampl = @FGEN_Ampl_10kHz
  4.141  CALL         Sub Setup /FGEN
  4.142  M8901        10kH                                        H0 L0    P+

  4.143  IF           ZCMP(@LO_Freq, "1.600053 GHz")
  4.144  8901         50pct                        600.53MH          AM N
  4.145  ELSE
  4.146  8901         50pct                        120.53MH          AM N
  4.147  ENDIF

  4.148  MATH         Acc = (REFACC() / MEM) * 100

  4.149  IF           MEM < AMmin
  4.150  MATH         AMmin = MEM; AccAMmin = Acc
  4.151  ELSEIF       MEM > AMmax
  4.152  MATH         AMmax = MEM; AccAMmin = Acc
  4.153  ENDIF

  4.154  MATH         MEM = CRND((20 * LOG(AMmax / AMmin)), 0.01)
# Compute resulting system accuracy and convert to dB.
  4.155  MATH         M[1] = PCTTODBV_D(RSS2(AccAMmin, AccAMmax))

  4.156  HEAD
  4.157  HEAD         -2
  4.158  END
