﻿Anritsu Company                                             MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub MG369XB Connection /ML2437
DATE:                  2009-08-21 09:53:21
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       253
CONFIGURATION:         Anritsu ML2437A
STANDARD:              Anritsu 41KC-10
STANDARD:              Anritsu 41V-10
=============================================================================
#
#  Procedure Author:
#        DAC
#
#  Model(s) Covered:
#        MG369XB
#
#  Compatibility:
#        MET/CAL 7.20E or later
#
#  Subprocedures:
#        Sub Anritsu Power Sensor Get Series
#        Sub Anritsu Power Sensor Get Connector Type
#        Sub Anritsu Power Sensor Get Frequency Type
#        Sub Anritsu Power Sensor Get Frequency Range
#        Sub Anritsu Power Sensor Get Dynamic Range
#        Sub Anritsu ML2430A Get Power Sensor Model
#        Sub MG369XB Init Connection Flags
#        Sub Audible Prompt
#
#  Required Files:
#        MG369XB_ML2430A_SC7400_K.jpg
#        MG369XB_ML2430A_SC7400_K_10dB.jpg
#        MG369XB_ML2430A_SC7400_V.jpg
#        MG369XB_ML2430A_SC7400_V_10dB.jpg
#        MG369XB_ML2430A_MA24X4.jpg
#        MG369XB_ML2430A_MA24X4_10dB.jpg
#        MG369XB_ML2430A_MA24X5.jpg
#        MG369XB_ML2430A_MA24X5_10dB.jpg
#        MG369XB_ML2430A_SC7430.jpg
#        MG369XB_ML2430A_SC7430_10dB.jpg
#        MG369XB_ML2430A_SC7570.jpg
#        MG369XB_ML2430A_SC7570_10dB.jpg
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  IF           ISVAR("@PS")
  1.002  MATH         CurrentPS = @PS
  1.003  ELSE
  1.004  MATH         CurrentPS = ""
  1.005  ENDIF

# Get specified power sensor model based on freq and connection type.
  1.006  CALL         Sub MG369XB Get Specified Power Sensor

# See if power sensor is changing.
  1.007  IF           NOT(ZCMP(CurrentPS, @PS))
  1.008  IEEE         RF0
  1.009  MATH         @ML2430A_Ch = "A"
  1.010  CALL         Sub Anritsu ML2430A Get Power Sensor Model
  1.011  CALL         Sub Anritsu Power Sensor Get Series
  1.012  CALL         Sub Anritsu Power Sensor Get Connector Type
  1.013  CALL         Sub Anritsu Power Sensor Get Frequency Type
  1.014  CALL         Sub Anritsu Power Sensor Get Frequency Range
  1.015  CALL         Sub Anritsu Power Sensor Get Dynamic Range

# Make sure power sensor is capable of measurement.
  1.016  IF           @LvldBm > +19
  1.017  MATH         Power = @LvldBm - 10
  1.018  ELSE
  1.019  MATH         Power = @LvldBm
  1.020  ENDIF

  1.021  IF           (Power < @PS_MinLvl) || (Power > @PS_MaxLvl)
  1.022  DISP         [V Power] dBm is outside [V @PS] range:
  1.022  DISP         [32] [V @PS_MinLvl] dBm to [V @PS_MaxLvl] dBm
  1.022  DISP
  1.023  END
  1.024  ENDIF

  1.025  MATH         Freq = @FreqGHz * 1E+9

  1.026  IF           (Freq < @PS_MinFreq) || (Freq > @PS_MaxFreq)
  1.027  MATH         Freq = ENGR_NSD(Freq, "Hz", 3)
  1.028  MATH         PS_MinFreq = ENGR_NSD(@PS_MinFreq, "Hz", 3)
  1.029  MATH         PS_MaxFreq = ENGR_NSD(@PS_MaxFreq, "Hz", 3)
  1.030  DISP         [V Freq] is outside [V @PS] range:
  1.030  DISP         [32] [V PS_MinFreq] to [V PS_MaxFreq]
  1.030  DISP
  1.031  END
  1.032  ENDIF

  1.033  TARGET
  1.034  CALL         Sub Audible Prompt

  1.035  IF           FIND(@ML2430A_Sensor, @PS, 1)
  1.036  OPBR         -z Does the power sensor need to be zero'd and cal'd?
  1.037  ELSE
  1.038  DISP         Connect [V @PS] to ML2430A Sensor A Input.
  1.039  MATH         MEM1 = 1
  1.040  ENDIF

  1.041  IF           MEM1
  1.042  CALL         Sub Audible Prompt

  1.043  IF           ZCMP(@PS_Con, "N")
  1.044  DISP         Connect [V @PS] to ML2430A CALIBRATOR output.
  1.045  ELSEIF       ZCMP(@PS_Con, "K")
  1.046  DISP         Connect [V @PS] to ML2430A CALIBRATOR output using a
  1.046  DISP         Type N (m) to Type K (f) adapter, Anritsu P/N 34NKF50.
  1.047  ELSEIF       ZCMP(@PS_Con, "V")
  1.048  DISP         Connect [V @PS] to ML2430A CALIBRATOR output using a
  1.048  DISP         Type V (f) to Type K (m) adapter, Anritsu P/N 34VFK50 &
  1.048  DISP         Type N (m) to Type K (f) adapter, Anritsu P/N 34NKF50.
  1.049  ENDIF

  1.050  ML2437       Zero; PowerSensor = [V @PS]
  1.051  ML2437       Cal;  PowerSensor = [V @PS]
  1.052  ENDIF

  1.053  ENDIF        ; Power sensor change

# Determine required connection.

# SC7400
  1.054  IF           ZCMP(@PS, "SC7400")

  1.055  IF           ZCMP(@MG369XB_Con, "K")

  1.056  IF           @LvldBm > +19
  1.057  MATH         ReqCon = "MG369XB_ML2430A_SC7400_K_10dB"
  1.058  ELSE
  1.059  MATH         ReqCon = "MG369XB_ML2430A_SC7400_K"
  1.060  ENDIF

  1.061  ELSEIF       ZCMP(@MG369XB_Con, "V")

  1.062  IF           @LvldBm > +19
  1.063  MATH         ReqCon = "MG369XB_ML2430A_SC7400_V_10dB"
  1.064  ELSE
  1.065  MATH         ReqCon = "MG369XB_ML2430A_SC7400_V"
  1.066  ENDIF

  1.067  ENDIF        ; ZCMP(@MG369XB_Con, "K")

# MA24X4
  1.068  ELSEIF       ZCMP(@PS_FreqType, "MA24X4")

  1.069  IF           @LvldBm > +19
  1.070  MATH         ReqCon = "MG369XB_ML2430A_MA24X4_10dB"
  1.071  ELSE
  1.072  MATH         ReqCon = "MG369XB_ML2430A_MA24X4"
  1.073  ENDIF

# MA24X5
  1.074  ELSEIF       ZCMP(@PS_FreqType, "MA24X5")

  1.075  IF           @LvldBm > +19
  1.076  MATH         ReqCon = "MG369XB_ML2430A_MA24X5_10dB"
  1.077  ELSE
  1.078  MATH         ReqCon = "MG369XB_ML2430A_MA24X5"
  1.079  ENDIF

# SC7430
  1.080  ELSEIF       ZCMP(@PS_FreqType, "SC7430")

  1.081  IF           @LvldBm > +19
  1.082  MATH         ReqCon = "MG369XB_ML2430A_SC7430_10dB"
  1.083  ELSE
  1.084  MATH         ReqCon = "MG369XB_ML2430A_SC7430"
  1.085  ENDIF

# SC7570
  1.086  ELSEIF       ZCMP(@PS_FreqType, "SC7570")

  1.087  IF           @LvldBm > +19
  1.088  MATH         ReqCon = "MG369XB_ML2430A_SC7570_10dB"
  1.089  ELSE
  1.090  MATH         ReqCon = "MG369XB_ML2430A_SC7570"
  1.091  ENDIF

  1.092  ELSE
  1.093  DISP         No connection picture available for [V @PS].
  1.094  END
  1.095  ENDIF

# See if connection requirements have changed.
  1.096  IF           NOT(ZCMP(@MG369XB_ML2430_Con, ReqCon))
  1.097  IEEE         RF0
  1.098  CALL         Sub Audible Prompt
  1.099  MATH         SamePS        = ZCMP(@PS, CurrentPS)
  1.100  MATH         Using10dB     = FIND(@MG369XB_ML2430_Con, "10dB", 1)
  1.101  MATH         DoNotNeed10dB = NOT(FIND(ReqCon, "10dB", 1))

  1.102  IF           SamePS && Using10dB && DoNotNeed10dB
  1.103  DISP         Remove the 10 dBm attenuator and reconnect the [V @PS]
  1.103  DISP         to the UUT.
  1.104  ELSEIF       ZCMP(ReqCon, "MG369XB_ML2430A_SC7400_K")
  1.105  PIC          MG369XB_ML2430A_SC7400_K
  1.106  ELSEIF       ZCMP(ReqCon, "MG369XB_ML2430A_SC7400_K_10dB")
  1.107  PIC          MG369XB_ML2430A_SC7400_K_10dB
  1.108  ELSEIF       ZCMP(ReqCon, "MG369XB_ML2430A_SC7400_V")
  1.109  PIC          MG369XB_ML2430A_SC7400_V
  1.110  ELSEIF       ZCMP(ReqCon, "MG369XB_ML2430A_SC7400_V_10dB")
  1.111  PIC          MG369XB_ML2430A_SC7400_V_10dB
  1.112  ELSEIF       ZCMP(ReqCon, "MG369XB_ML2430A_MA24X4")
  1.113  PIC          MG369XB_ML2430A_MA24X4
  1.114  ELSEIF       ZCMP(ReqCon, "MG369XB_ML2430A_MA24X4_10dB")
  1.115  PIC          MG369XB_ML2430A_MA24X4_10dB
  1.116  ELSEIF       ZCMP(ReqCon, "MG369XB_ML2430A_MA24X5")
  1.117  PIC          MG369XB_ML2430A_MA24X5
  1.118  ELSEIF       ZCMP(ReqCon, "MG369XB_ML2430A_MA24X5_10dB")
  1.119  PIC          MG369XB_ML2430A_MA24X5_10dB
  1.120  ELSEIF       ZCMP(ReqCon, "MG369XB_ML2430A_SC7430")
  1.121  PIC          MG369XB_ML2430A_SC7430
  1.122  ELSEIF       ZCMP(ReqCon, "MG369XB_ML2430A_SC7430_10dB")
  1.123  PIC          MG369XB_ML2430A_SC7430_10dB
  1.124  ELSEIF       ZCMP(ReqCon, "MG369XB_ML2430A_SC7570")
  1.125  PIC          MG369XB_ML2430A_SC7570
  1.126  ELSEIF       ZCMP(ReqCon, "MG369XB_ML2430A_SC7570_10dB")
  1.127  PIC          MG369XB_ML2430A_SC7570_10dB
  1.128  ELSE
  1.129  DISP         No connection picture available for [V @PS].
  1.130  END
  1.131  ENDIF

  1.132  IF           FIND(ReqCon, "10dB", 1) && ZCMP(@MG369XB_Con, "K")
  1.133  STD          Anritsu 41KC-10
  1.134  MATH         @Anritsu41xAttenuator = "Anritsu 41KC-10"
  1.135  ELSEIF       FIND(ReqCon, "10dB", 1) && ZCMP(@MG369XB_Con, "V")
  1.136  STD          Anritsu 41V-10
  1.137  MATH         @Anritsu41xAttenuator = "Anritsu 41V-10"
  1.138  ELSE
  1.139  MATH         @Anritsu41xAttenuator = ""
  1.140  ENDIF

  1.141  CALL         Sub MG369XB Init Connection Flags
  1.142  MATH         @MG369XB_ML2430_Con = ReqCon
  1.143  ENDIF        ; NOT(ZCMP(@MG369XB_ML2430_Con, ReqCon))

  1.144  END
